@@ -1,6 +1,7 @@
 ## The following values are updated with each Bioc release; see .onLoad
-BIOC_VERSION <- package_version("2.14")    # Bioc version for this package
-R_VERSION <- package_version("3.1.0")      # R version for this package
+BIOC_VERSION <- package_version("3.1")     # Bioc version for this package
+R_VERSION_MAX <- package_version("3.3.0")  # Maximum version of R for
+                                           # this version of BiocInstaller
 IS_USER <- TRUE                            # TRUE if this version of
                                            # Bioconductor is the
                                            # current release version
@@ -19,27 +20,28 @@ IS_DOWNGRADEABLE <- FALSE                  # TRUE if an older version
                                            # (release or devel) of
                                            # Bioconductor is available
                                            # for this version of R
-UPGRADE_VERSION <- package_version("3.0")  # Bioconductor version for
+UPGRADE_VERSION <- package_version("3.2")  # Bioconductor version for
                                            # upgrade, if
                                            # IS_UPGRADEABLE == TRUE
-DOWNGRADE_VERSION <- package_version("2.14") # Bioconductor verson for
+DOWNGRADE_VERSION <- package_version("3.0") # Bioconductor version for
                                            # downgrade, if
                                            # IS_DOWNGRADEABLE == # TRUE
 
-NEXT_R_DEVEL_VERSION <- "3.2.0" # next (not-yet-supported) version of R
+NEXT_R_DEVEL_VERSION <- "3.3.0" # next (not-yet-supported) version of R
 
 ## Change when the status of MBNI changes. 
 ## Make sure this change is propagated to users, even 
 ## if builds have stopped for a particular version of BioC.
-## See biocLite.R:.biocinstallRepos to include / exclude package types
+## See biocLite.R:biocinstallRepos to include / exclude package types
 includeMBNI <- FALSE
 mbniUrl <- "http://brainarray.mbni.med.umich.edu/bioc"
 
-globalVariables("contribUrl")           # used in 'bootstrap' functions
+globalVariables("repos")           # used in 'bootstrap' functions
 
 .onAttach <-
     function(libname, pkgname) 
 {
+    Rversion <- getRversion()
     .message("Bioconductor version %s (BiocInstaller %s), ?biocLite for help",
              biocVersion(), packageVersion("BiocInstaller"))
     if (IS_END_OF_LIFE) {
@@ -50,5 +52,13 @@ globalVariables("contribUrl")           # used in 'bootstrap' functions
             .message("A new version of Bioconductor is available after
                       installing the most recent version of R; see
                       http://bioconductor.org/install")
+    } else if (Rversion >= R_VERSION_MAX) {
+        if (Rversion >= NEXT_R_DEVEL_VERSION)
+            .message("Bioconductor does not yet support R version %s", Rversion)
+        else
+            .warning("BiocInstaller version %s is too old for R version %s;
+                      remove.packages(\"BiocInstaller\") then
+                      source(\"http://bioconductor.org/biocLite.R\")",
+                     BIOC_VERSION, Rversion)
     }
 }
